// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:gap/gap.dart';
import 'package:wyatt_ui_components/wyatt_ui_components.dart';
import 'package:wyatt_ui_kit/src/components/cards/widgets/card_text.dart';

const _titlesLineSpacing = 5.0;

class SkillCardTitles extends StatelessWidget {
  const SkillCardTitles({
    this.axis,
    this.title,
    this.subtitle,
    this.titleStyle,
    this.subtitleStyle,
    super.key,
  });

  /// The axis of the card header.
  final Axis? axis;

  /// The title of the card.
  final TextWrapper? title;

  /// The subtitle of the card.
  final TextWrapper? subtitle;

  /// Styles the title of the card.
  final TextStyle? titleStyle;

  /// Styles the subtitle of the card.
  final TextStyle? subtitleStyle;

  @override
  Widget build(BuildContext context) => Column(
        crossAxisAlignment: axis == Axis.horizontal
            ? CrossAxisAlignment.start
            : CrossAxisAlignment.center,
        children: [
          if (title != null) ...[
            CardText.fromWrapper(
              title!,
              style: titleStyle,
              textType: TextType.title,
            ),
          ],
          if (subtitle != null) ...[
            const Gap(_titlesLineSpacing),
            CardText.fromWrapper(
              subtitle!,
              style: subtitleStyle,
              textType: TextType.subtitle,
            ),
          ],
        ],
      );
}
